/*
	File:		ISOString.cpp

	Contains:	Routines for manipulating ISO Strings

	Written by:	Vincent Lo

	Copyright:	 1993-1994 by Apple Computer, Inc., all rights reserved.

	Change History (most recent first):

		 <3>	 9/29/94	RA		1189812: Mods for 68K build.
		 <2>	 6/18/94	MB		Correct memory includes
		 <1>	  6/2/94	VL		first checked in

	To Do:
*/

#ifndef _ISOSTR_
#include "ISOStr.h"
#endif

#ifndef _EXCEPT_
#include "Except.h"
#endif

#ifndef _ODMEMORY_
#include "ODMemory.h"
#endif

#ifndef __STRING__
#include <String.h>
#endif

ODISOStr ODISOStrCopy (ODISOStr dest, const ODISOStr source)
{
	strcpy(dest, source);
	
	return dest;
}

ODISOStr ODISOStrNCopy (ODISOStr dest, const ODISOStr source, ODULong length)
{
	strncpy(dest, source, (size_t)length);
	
	return dest;
}

ODISOStr ODISOStrConcat (ODISOStr dest, const ODISOStr source)
{
	strcat(dest, source);
	
	return dest;
}

ODISOStr ODISOStrNConcat (ODISOStr dest, const ODISOStr source, ODULong length)
{
	strncat(dest, source, (size_t)length);
	
	return dest;
}

ODSLong ODISOStrCompare (const ODISOStr iso1, const ODISOStr iso2)
{
	return strcmp(iso1, iso2);
}

ODSLong ODISOStrNCompare (const ODISOStr iso1, const ODISOStr iso2, ODULong length)
{
	return strncmp(iso1, iso2, (size_t)length);
}

ODBoolean ODISOStrEqual (const ODISOStr iso1, const ODISOStr iso2)
{
	return (strcmp(iso1, iso2) == 0);
}

ODULong ODISOStrLength (const ODISOStr iso)
{
	return strlen(iso);
}

ODISOStr ODISOStrFromCStr (const char* cstring)
{
	ODULong	cstringSize;
	ODISOStr	isoStr;
	
	cstringSize = strlen(cstring);
	isoStr = (ODISOStr) ODNewPtr(cstringSize + 1, kDefaultHeapID);
	strcpy(isoStr, cstring);
	
	return isoStr;
}

